{% extends "base.html" %}
{% load i18n %}

{% block title %}{% trans "Password reset successful" %} - {{ block.super }}{% endblock %}

{% block main %}
<div class="row">
  <div class="large-6 large-centered columns">
    <h1>{% trans "Password reset successful" %}</h1>
    {% include "towel/_messages.html" %}
    <p>{% trans "We've emailed you instructions for setting your password to the email address you submitted. You should be receiving it shortly." %}</p>
  </div>
</div>
{% endblock %}
