{% extends base_template|default:"base.html" %}

{% load i18n modelview_detail %}

{% block title %}{{ object }} - {{ block.super }}{% endblock %}

{% block page-header %}<div class="page-header">
  <h1>{{ object }}</h1>
</div>
{% endblock %}

{% block content %}
<table>
{% for title, value in object|model_details %}
    <tr class="{% cycle "odd" "even" %}">
        <th>{{ title|capfirst }}</th>
        <td>{{ value }}</td>
    </tr>
{% endfor %}
</table>

<div class="buttons">
  <a href="{{ object.urls.edit }}" class="button">{% trans "edit" %}</a>
  <a href="{{ object.urls.delete }}" class="button alert">{% trans "delete" %}</a>
</div>
{% endblock %}
