{% extends "base.html" %}

{% load i18n %}
{% load url from future %}

{% block main %}
<div class="row">
  <div class="large-6 large-centered columns">
    <h1>{% trans "Signed out" %}</h1>
    {% include "towel/_messages.html" %}
    <p>{% trans "Thanks for spending your time with us!" %}</p>

    <br>
    <a href="{% url 'login' %}" class="button">{% trans "Sign in" %}</a>
  </div>
</div>
{% endblock %}
