{% extends "base.html" %}
{% load i18n towel_form_tags %}

{% block title %}{% trans "Set password" %} - {{ block.super }}{% endblock %}

{% block main %}
<div class="row">
  <div class="large-6 large-centered columns">
    <h1>{% trans "Set password" %}</h1>
    {% include "towel/_messages.html" %}
    <form action="." method="post">
      {% csrf_token %}
      {% form_errors form %}
      {% form_item form.new_password1 %}
      {% form_item form.new_password2 %}

      <button type="submit" class="button">{% trans "Set password" %}</button>
      <script type="text/javascript">document.getElementById("id_old_password").focus();</script>
    </form>
  </div>
</div>
{% endblock %}
