{% load i18n verbose_name_tags %}
<div class="form-errors alert-box alert" data-alert>
  <a class="close" href="#">&times;</a>

  <strong>{% trans "Please correct the errors below." %}</strong>

  {% for form in forms %}
    {{ form.non_field_errors }}
  {% endfor %}

  {% for formset in formsets %}
    {% for error in formset.non_field_errors %}
      {{ formset.non_field_errors }}
    {% endfor %}
    {% for form in formset %}
      {% for error in form.non_field_errors %}<br>{{ error }}{% endfor %}
    {% endfor %}
  {% endfor %}
</div>
