{% load foundation_tags %}
<div
  class="{{ additional_classes|default:'' }} {{ item.field.required|yesno:'required,' }} {{ item.errors|yesno:'error,' }} type-{{ type_class }} field-{{ item.name }}"
  {% if 'date' in type_class %}data-date-format="{% date_format %}"{% endif %}
  >
  {% if "hidden" in type_class %}
    {{ item }}
  {% elif is_checkbox %}
    <label for="{{ item.auto_id }}" class="checkbox">
      {{ item }}
      {{ item.label }}
      {% if item.field.help_text %}
        <span>{{ item.field.help_text }}</span>
      {% endif %}
    </label>
  {% else %}
    <label for="{{ item.auto_id }}">
      {{ item.label }}
      {% if item.field.help_text %}
        <span>{{ item.field.help_text }}</span>
      {% endif %}
    </label>
    {{ item }}
    {% if item.errors %}
      <small class="error">
        {% for error in item.errors %}{{ error }}<br>{% endfor %}
      </small>
    {% endif %}
  {% endif %}
</div>
